.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT



.. _canary.plugins.subcommands.run:

run
===

.. automodule:: _canary.plugins.subcommands.run
   :members:
   :undoc-members:
   :show-inheritance:
